@@ -192,7 +192,7 @@ Returns a L<Google::Ads::AdWords::v201402::CampaignService::getResponse|Google::
 
 =head3 mutate
 
-Adds, updates, or deletes campaigns. <p class="note"><b>Note:</b> {@link CampaignOperation} does not support the <code>REMOVE</code> operator. To delete a campaign, set its {@link Campaign#status status} to <code>DELETED</code>.</p> @param operations A list of unique operations. The same campaign cannot be specified in more than one operation. @return The list of updated campaigns, returned in the same order as the <code>operations</code> array. @throws ApiException if problems occurred while updating campaign information. 
+Adds, updates, or removes campaigns. <p class="note"><b>Note:</b> {@link CampaignOperation} does not support the <code>REMOVE</code> operator. To remove a campaign, set its {@link Campaign#status status} to {@code REMOVED}.</p> @param operations A list of unique operations. The same campaign cannot be specified in more than one operation. @return The list of updated campaigns, returned in the same order as the <code>operations</code> array. @throws ApiException if problems occurred while updating campaign information. 
 
 Returns a L<Google::Ads::AdWords::v201402::CampaignService::mutateResponse|Google::Ads::AdWords::v201402::CampaignService::mutateResponse> object.
 
@@ -216,6 +216,6 @@ Returns a L<Google::Ads::AdWords::v201402::CampaignService::queryResponse|Google
 
 =head1 AUTHOR
 
-Generated by SOAP::WSDL on Thu Jun 26 19:31:14 2014
+Generated by SOAP::WSDL on Thu Jul 31 11:57:00 2014
 
 =cut
