@@ -19,16 +19,9 @@ package Google::Ads::Common::Constants;
 use strict;
 use version;
 
-# Main version number that the rest of the modules on this package pick up of.
-our $VERSION = qv("2.10.0");
-
-use constant CLIENT_LOGIN_DEPRECATION_MESSAGE =>
-    "ClientLogin has been officially deprecated" .
-    " as of April 20, 2012, for more information consult our documentation at" .
-    " https://developers.google.com/accounts/docs/AuthForInstalledApps.\n" .
-    "Instead, we strongly recommend you migrate to OAuth2.0, read our" .
-    " client library guide to get started today at" .
-    " https://github.com/googleads/googleads-perl-lib/wiki/Using-OAuth-2.0";
+# Main version number that the rest of the modules on this package pick up
+# off of.
+our $VERSION = qv("3.0.0");
 
 use constant NO_AUTH_HANDLER_IS_SETUP_MESSAGE =>
     "The library couldn't find any authorization mechanism set up to " .
